package com.huatek.busi.mapper;

import com.github.pagehelper.Page;
import com.huatek.busi.dto.LabReportBasisDataStatisticsDto;
import com.huatek.busi.dto.LabReportParamDataDto;
import com.huatek.busi.dto.LabReportParamDataDtos;
import com.huatek.busi.where.LabReportBasisDataStatisticsWhereVo;
import com.huatek.busi.where.LabReportParamDataSelectVo;
import org.apache.ibatis.annotations.Param;
import org.springframework.stereotype.Repository;

import java.util.List;
import java.util.Map;

@Repository
public interface LabReportParamDataMapper {
    List<LabReportParamDataDtos> findList(Map<String, Object> map);

    int delete(@Param("refId") String refId);

    Page<LabReportParamDataDto> findAll(LabReportParamDataSelectVo labReportParamDataSelectVo);

    List<LabReportBasisDataStatisticsDto> statistics(LabReportBasisDataStatisticsWhereVo labReportBasisDataStatisticsVo);

    int updateByRefIds(@Param("refIds") List<String> refIds);

    int deleteBlq(@Param("refId") String refId);

    int deleteDl(@Param("refId") String refId);

    int deleteKgg(@Param("refId") String refId);

    int deleteGen(@Param("refId") String refId);

    Page<LabReportParamDataDto> findBlqAll(LabReportParamDataSelectVo labReportParamDataSelectVo);

    Page<LabReportParamDataDto> findDlAll(LabReportParamDataSelectVo labReportParamDataSelectVo);

    Page<LabReportParamDataDto> findKggAll(LabReportParamDataSelectVo labReportParamDataSelectVo);

    Page<LabReportParamDataDto> findGenAll(LabReportParamDataSelectVo labReportParamDataSelectVo);

    int updateBlqByRefIds(@Param("refIds") List<String> refIds);

    int updateDlByRefIds(@Param("refIds") List<String> refIds);

    int updateKggByRefIds(@Param("refIds") List<String> refIds);

    int updateGenByRefIds(@Param("refIds") List<String> refIds);
}
